@@ -79,6 +79,11 @@ class ResourceShare(
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-extensions.ram.ResourceShare",
 ):
+    '''Creates a resource share that can used to share AWS resources with other AWS accounts, organizations, or organizational units (OU's).
+
+    :see: `AWS::RAM::ResourceShare <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html>`_
+    '''
+
     def __init__(
         self,
         scope: constructs.Construct,
@@ -98,11 +103,11 @@ class ResourceShare(
 
         :param scope: A CDK Construct that will serve as this stack's parent in the construct tree.
         :param id: A name to be associated with the stack and used in resource naming. Must be unique within the context of 'scope'.
-        :param allow_external_principals: 
-        :param auto_discover_accounts: 
-        :param name: 
-        :param principals: 
-        :param resources: 
+        :param allow_external_principals: Specifies whether principals outside your organization in AWS Organizations can be associated with a resource share. A value of ``true`` lets you share with individual AWS accounts that are not in your organization. A value of ``false`` only has meaning if your account is a member of an AWS Organization. Default: true
+        :param auto_discover_accounts: Controls whether the resource share should attempt to search for AWS accounts that are part of the same CDK application. Any accounts is finds will be added to the resource automatically and will be able to use the shared resources.
+        :param name: Specifies the name of the resource share.
+        :param principals: Specifies a list of one or more principals to associate with the resource share.
+        :param resources: Specifies a list of AWS resources to share with the configured principal accounts and organizations.
         :param account: The AWS account ID this resource belongs to. Default: - the resource is in the same account as the stack it belongs to
         :param environment_from_arn: ARN to deduce region and account from. The ARN is parsed and the account and region are taken from the ARN. This should be used for imported resources. Cannot be supplied together with either ``account`` or ``region``. Default: - take environment from ``account``, ``region`` parameters, or use Stack environment.
         :param physical_name: The value passed in by users to the physical name prop of the resource. - ``undefined`` implies that a physical name will be allocated by CloudFormation during deployment. - a concrete value implies a specific physical name - ``PhysicalName.GENERATE_IF_NEEDED`` is a marker that indicates that a physical will only be generated by the CDK if it is needed for cross-environment references. Otherwise, it will be allocated by CloudFormation. Default: - The physical name will be allocated by CloudFormation at deployment time
@@ -158,16 +163,40 @@ class ResourceShare(
     @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
+        '''Specifies the name of the resource share.
+
+        :see: `ResourceShare.Name <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html#cfn-ram-resourceshare-name>`_
+        :group: Inputs
+        '''
         return typing.cast(builtins.str, jsii.get(self, "name"))
 
     @builtins.property
     @jsii.member(jsii_name="resource")
     def resource(self) -> aws_cdk.aws_ram.CfnResourceShare:
+        '''The underlying ResourceShare CloudFormation resource.
+
+        :see: `AWS::RAM::ResourceShare <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html>`_
+        :group: Resources
+        '''
         return typing.cast(aws_cdk.aws_ram.CfnResourceShare, jsii.get(self, "resource"))
 
     @builtins.property
     @jsii.member(jsii_name="allowExternalPrincipals")
     def allow_external_principals(self) -> typing.Optional[builtins.bool]:
+        '''Specifies whether principals outside your organization in AWS Organizations can be associated with a resource share.
+
+        A value of ``true``
+        lets you share with individual AWS accounts that are not in your
+        organization. A value of ``false`` only has meaning if your account is a
+        member of an AWS Organization.
+
+        In order for an account to be auto discovered it must be part of the same
+        CDK application. It must also be an explicitly defined environment and not
+        environment agnostic.
+
+        :see: `CDK Environments <https://docs.aws.amazon.com/cdk/v2/guide/environments.html>`_
+        :group: Inputs
+        '''
         return typing.cast(typing.Optional[builtins.bool], jsii.get(self, "allowExternalPrincipals"))
 
 
@@ -206,11 +235,11 @@ class ResourceShareProps(aws_cdk.ResourceProps):
         :param environment_from_arn: ARN to deduce region and account from. The ARN is parsed and the account and region are taken from the ARN. This should be used for imported resources. Cannot be supplied together with either ``account`` or ``region``. Default: - take environment from ``account``, ``region`` parameters, or use Stack environment.
         :param physical_name: The value passed in by users to the physical name prop of the resource. - ``undefined`` implies that a physical name will be allocated by CloudFormation during deployment. - a concrete value implies a specific physical name - ``PhysicalName.GENERATE_IF_NEEDED`` is a marker that indicates that a physical will only be generated by the CDK if it is needed for cross-environment references. Otherwise, it will be allocated by CloudFormation. Default: - The physical name will be allocated by CloudFormation at deployment time
         :param region: The AWS region this resource belongs to. Default: - the resource is in the same region as the stack it belongs to
-        :param allow_external_principals: 
-        :param auto_discover_accounts: 
-        :param name: 
-        :param principals: 
-        :param resources: 
+        :param allow_external_principals: Specifies whether principals outside your organization in AWS Organizations can be associated with a resource share. A value of ``true`` lets you share with individual AWS accounts that are not in your organization. A value of ``false`` only has meaning if your account is a member of an AWS Organization. Default: true
+        :param auto_discover_accounts: Controls whether the resource share should attempt to search for AWS accounts that are part of the same CDK application. Any accounts is finds will be added to the resource automatically and will be able to use the shared resources.
+        :param name: Specifies the name of the resource share.
+        :param principals: Specifies a list of one or more principals to associate with the resource share.
+        :param resources: Specifies a list of AWS resources to share with the configured principal accounts and organizations.
         '''
         if __debug__:
             type_hints = typing.get_type_hints(ResourceShareProps.__init__)
@@ -292,26 +321,55 @@ class ResourceShareProps(aws_cdk.ResourceProps):
 
     @builtins.property
     def allow_external_principals(self) -> typing.Optional[builtins.bool]:
+        '''Specifies whether principals outside your organization in AWS Organizations can be associated with a resource share.
+
+        A value of ``true``
+        lets you share with individual AWS accounts that are not in your
+        organization. A value of ``false`` only has meaning if your account is a
+        member of an AWS Organization.
+
+        :default: true
+
+        :see: `ResourceShare.AllowExternalPrinicpals <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html#cfn-ram-resourceshare-allowexternalprincipals>`_
+        '''
         result = self._values.get("allow_external_principals")
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def auto_discover_accounts(self) -> typing.Optional[builtins.bool]:
+        '''Controls whether the resource share should attempt to search for AWS accounts that are part of the same CDK application.
+
+        Any accounts is finds
+        will be added to the resource automatically and will be able to use the
+        shared resources.
+        '''
         result = self._values.get("auto_discover_accounts")
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def name(self) -> typing.Optional[builtins.str]:
+        '''Specifies the name of the resource share.
+
+        :see: `ResourceShare.Name <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html#cfn-ram-resourceshare-name>`_
+        '''
         result = self._values.get("name")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def principals(self) -> typing.Optional[typing.List[ISharedPrincipal]]:
+        '''Specifies a list of one or more principals to associate with the resource share.
+
+        :see: `ResourceShare.Prinicipals <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html#cfn-ram-resourceshare-principals>`_
+        '''
         result = self._values.get("principals")
         return typing.cast(typing.Optional[typing.List[ISharedPrincipal]], result)
 
     @builtins.property
     def resources(self) -> typing.Optional[typing.List[ISharedResource]]:
+        '''Specifies a list of AWS resources to share with the configured principal accounts and organizations.
+
+        :see: `ResourceShare.ResourceArns <https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html#cfn-ram-resourceshare-resourcearns>`_
+        '''
         result = self._values.get("resources")
         return typing.cast(typing.Optional[typing.List[ISharedResource]], result)
 
